import micromagneticmodel as mm


class Evolver(mm.abstract.Abstract):
    """An abstract class for deriving evolvers."""

    pass
